@@ -636,7 +636,7 @@
  *  0: Never allow the GPU to be powered down (default).
  *  1: Power down the GPU when it is not initialized.
 
-
+ *  2: Power down the GPU after it has been inactive for some time.
 
  */
 #define __NV_DYNAMIC_POWER_MANAGEMENT DynamicPowerManagement
@@ -646,8 +646,25 @@
 #define NV_REG_DYNAMIC_POWER_MANAGEMENT_NEVER   0
 #define NV_REG_DYNAMIC_POWER_MANAGEMENT_COARSE  1
 
+#define NV_REG_DYNAMIC_POWER_MANAGEMENT_FINE    2
 
 
+/*
+ * Option: RegisterPCIDriver
+ *
+ * Description:
+ *
+ * When this option is enabled, the NVIDIA driver will register with
+ * PCI subsystem.
+ *
+ * Possible values:
+ *
+ *  1 - register as PCI driver (default)
+ *  0 - do not register as PCI driver
+ */
+
+#define __NV_REGISTER_PCI_DRIVER  RegisterPCIDriver
+#define NV_REG_REGISTER_PCI_DRIVER NV_REG_STRING(__NV_REGISTER_PCI_DRIVER)
 
 #if defined(NV_DEFINE_REGISTRY_KEY_TABLE)
 
@@ -682,6 +699,11 @@ NV_DEFINE_REG_ENTRY_GLOBAL(__NV_VMALLOC_HEAP_MAX_SIZE, 0);
 NV_DEFINE_REG_ENTRY_GLOBAL(__NV_IGNORE_MMIO_CHECK, 0);
 NV_DEFINE_REG_ENTRY_GLOBAL(__NV_NVLINK_DISABLE, 0);
 
+
+
+NV_DEFINE_REG_ENTRY_GLOBAL(__NV_REGISTER_PCI_DRIVER, 1);
+
+
 NV_DEFINE_REG_STRING_ENTRY(__NV_REGISTRY_DWORDS, NULL);
 NV_DEFINE_REG_STRING_ENTRY(__NV_REGISTRY_DWORDS_PER_DEVICE, NULL);
 NV_DEFINE_REG_STRING_ENTRY(__NV_RM_MSG, NULL);
@@ -730,6 +752,7 @@ nv_parm_t nv_parms[] = {
         __NV_RM_PROFILING_ADMIN_ONLY_PARAMETER),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_PRESERVE_VIDEO_MEMORY_ALLOCATIONS),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_DYNAMIC_POWER_MANAGEMENT),
+    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_REGISTER_PCI_DRIVER),
     {NULL, NULL, NULL}
 };
 
